// Copyright (c) 2010 Moxie Marlinspike <moxie@thoughtcrime.org>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 3 of the
// License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA

var GoogleShare = {

  googleSharingManager: null,
  timerRunning: false,

  onLoad: function(event) {
    this.initializeGoogleSharingManager();
    this.registerStatusObserver();
    this.updateLocalStatus();
  },

  initializeGoogleSharingManager: function() {
    this.googleSharingManager = Components.classes['@thoughtcrime.org/googlesharingmanager;1']
    .getService().wrappedJSObject;
  },

  registerStatusObserver: function() {
    var observerService = Components.classes["@mozilla.org/observer-service;1"]
    .getService(Components.interfaces.nsIObserverService);
    observerService.addObserver(this, "googlesharing-status", false);
    observerService.addObserver(this, "googlesharing-activity", false);
  },

  observe: function(subject, topic, data) {
    if (topic == "googlesharing-status") {
      this.updateLocalStatus();
    } else if (topic == "googlesharing-activity" && 
	       this.googleSharingManager.isEnabled() && 
	       !this.timerRunning) 
    {
      this.startActivityFlash();
    }

  },

  stopActivityFlash: function() {
    this.timerRunning = false;
    if (this.googleSharingManager.isEnabled()) {
      document.getElementById("googlesharing-panel").setAttribute("style", "color: green;");
    }
  },

  startActivityFlash: function() {
    this.timerRunning = true;
    document.getElementById("googlesharing-panel").setAttribute("style", "color: lime;");
    window.setTimeout(function(thisObj) { thisObj.stopActivityFlash(); }, 200, this);
  },

  setEnabledStatus: function() {
    document.getElementById("googlesharing-panel").label="Google Sharing Enabled";
    document.getElementById("googlesharing-panel").setAttribute("style", "color: green;");
    document.getElementById("googlesharing-status-context").label = "Disable";
  },

  setDisabledStatus: function() {
    document.getElementById("googlesharing-panel").label = "Google Sharing Disabled"
    document.getElementById("googlesharing-panel").setAttribute("style", "color: red;");
    document.getElementById("googlesharing-status-context").label = "Enable";
  },

  updateSystemStatus: function() {
    this.googleSharingManager.setEnabled(!this.googleSharingManager.isEnabled());
    
    var observerService = Components.classes["@mozilla.org/observer-service;1"]
    .getService(Components.interfaces.nsIObserverService);  
    observerService.notifyObservers(observerService, "googlesharing-status", false);
  },

  updateLocalStatus: function() {
    (this.googleSharingManager.isEnabled() ? this.setEnabledStatus() : this.setDisabledStatus());
  },

  onStatusBarClick: function(event) {
    if (event.button != 0) return;
    this.updateSystemStatus();
    this.updateLocalStatus();
  }
};

window.addEventListener("load", function(e) { GoogleShare.onLoad(e); }, false); 

